@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 
-from debmutate.control import ControlEditor
 from lintian_brush.fixer import (
+    control,
     meets_minimum_certainty,
     report_result,
     fixed_lintian_tag,
@@ -27,7 +27,7 @@ except FileNotFoundError:
 default_section = None
 fixed = []
 
-with ControlEditor() as updater:
+with control as updater:
     default_section = updater.source.get("Section")
 
     for binary in updater.binaries:
@@ -46,5 +46,5 @@ with ControlEditor() as updater:
 # TODO(jelmer): If there is only a single binary package without section, just
 # set the section of the source package?
 report_result(
-    "Fix sections for %s." % ', '.join(['%s (%s => %s)' % v for v in fixed]),
+    "Fix sections for %s." % ', '.join(['%s (%s ⇒ %s)' % v for v in fixed]),
     certainty=CERTAINTY)
