@@ -804,7 +804,11 @@ def main():  # noqa: C901
                 "versions": versions_dict(),
                 "context": {
                     "specific_files": result.specific_files,
-                    "maintscript_removed": result.maintscript_removed,
+                    "maintscript_removed": [
+                        (name, [(lineno, pkg, str(version) if version else None)
+                                for (lineno, pkg, version) in entries], release)
+                        for (name, entries, release)
+                        in result.maintscript_removed],
                     "control_removed": result.control_removed,
                 }
             }, f)
